
#ifndef AKONADI_SEARCH_PIM_EXPORT_H
#define AKONADI_SEARCH_PIM_EXPORT_H

#ifdef AKONADI_SEARCH_PIM_STATIC_DEFINE
#  define AKONADI_SEARCH_PIM_EXPORT
#  define AKONADI_SEARCH_PIM_NO_EXPORT
#else
#  ifndef AKONADI_SEARCH_PIM_EXPORT
#    ifdef KF5AkonadiSearchPIM_EXPORTS
        /* We are building this library */
#      define AKONADI_SEARCH_PIM_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define AKONADI_SEARCH_PIM_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef AKONADI_SEARCH_PIM_NO_EXPORT
#    define AKONADI_SEARCH_PIM_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef AKONADI_SEARCH_PIM_DEPRECATED
#  define AKONADI_SEARCH_PIM_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_SEARCH_PIM_DEPRECATED_EXPORT
#  define AKONADI_SEARCH_PIM_DEPRECATED_EXPORT AKONADI_SEARCH_PIM_EXPORT AKONADI_SEARCH_PIM_DEPRECATED
#endif

#ifndef AKONADI_SEARCH_PIM_DEPRECATED_NO_EXPORT
#  define AKONADI_SEARCH_PIM_DEPRECATED_NO_EXPORT AKONADI_SEARCH_PIM_NO_EXPORT AKONADI_SEARCH_PIM_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef AKONADI_SEARCH_PIM_NO_DEPRECATED
#    define AKONADI_SEARCH_PIM_NO_DEPRECATED
#  endif
#endif

#endif /* AKONADI_SEARCH_PIM_EXPORT_H */
